/// <reference types="node" />
import type { ConfigurationParameters } from '@datadog/datadog-api-client/dist/packages/datadog-api-client-common/configuration';
export interface DDTransportOptions {
    /**
     * DataDog client configuration parameters.
     * @see https://datadoghq.dev/datadog-api-client-typescript/interfaces/client.Configuration.html
     */
    ddClientConf: ConfigurationParameters;
    /**
     * The integration name associated with your log: the technology from which
     * the log originated. When it matches an integration name, Datadog
     * automatically installs the corresponding parsers and facets.
     * @see https://docs.datadoghq.com/logs/log_collection/?tab=host#reserved-attributes
     */
    ddsource?: string;
    /**
     * Comma separated tags associated with your logs. Ex: "env:prod,org:finance"
     */
    ddtags?: string;
    /**
     * The name of the application or service generating the log events.
     * It is used to switch from Logs to APM, so make sure you define the same
     * value when you use both products.
     * @see https://docs.datadoghq.com/logs/log_collection/?tab=host#reserved-attributes
     */
    service?: string;
    /**
     * Error handler for when the submitLog() call fails. See readme on how to
     * properly implement this callback.
     */
    onError?: (err: string) => void;
}
export declare const convertLevel: (level: number | string) => string;
export default function (options: DDTransportOptions): Promise<import("stream").Transform & import("pino-abstract-transport").OnUnknown>;
