"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertLevel = void 0;
const pino_abstract_transport_1 = __importDefault(require("pino-abstract-transport"));
const datadog_api_client_1 = require("@datadog/datadog-api-client");
const convertLevel = (level) => {
    if (typeof level === 'string') {
        return level;
    }
    if (level == 60) {
        return 'fatal';
    }
    if (level >= 50) {
        return 'error';
    }
    if (level >= 40) {
        return 'warning';
    }
    if (level >= 30) {
        return 'log';
    }
    if (level >= 20) {
        return 'info';
    }
    return 'debug';
};
exports.convertLevel = convertLevel;
async function default_1(options) {
    const configuration = datadog_api_client_1.client.createConfiguration(options.ddClientConf);
    const apiInstance = new datadog_api_client_1.v2.LogsApi(configuration);
    return (0, pino_abstract_transport_1.default)(async function (source) {
        for await (const obj of source) {
            if (!obj) {
                return;
            }
            const logItem = {
                message: JSON.stringify({
                    ...obj,
                    level: (0, exports.convertLevel)(obj.level),
                }),
            };
            if (options.ddsource) {
                logItem.ddsource = options.ddsource;
            }
            if (options.ddtags) {
                logItem.ddtags = options.ddtags;
            }
            if (options.service) {
                logItem.service = options.service;
            }
            if (obj.hostname) {
                logItem.hostname = obj.hostname;
            }
            const params = {
                body: [logItem],
                contentEncoding: 'gzip',
            };
            try {
                await apiInstance.submitLog(params);
            }
            catch (e) {
                if (options.onError) {
                    options.onError(e);
                }
            }
        }
    });
}
exports.default = default_1;
//# sourceMappingURL=index.js.map